import { NgModule } from "@angular/core";
import { CommonModule } from "@angular/common";
import { RouterModule, Routes } from "@angular/router";
import { PermissionGuard } from "src/app/core/guard/permission.guard";
import { PermissionsEnum } from "src/app/model/auth/permissionsEnum";
import { SharedModule } from "src/app/modules/shared/shared.module";

const routes: Routes = [
  {
    path: "users",
    title: "Users | Maxlan",
    loadChildren: () =>
      import("src/app/modules/admin/administration/users/users.module").then(
        (m) => m.UsersModule,
      ),
    canActivate: [PermissionGuard],
    data: { permissions: [PermissionsEnum.users] },
  },
  {
    path: "roles",
    title: "Roles | Maxlan",
    loadChildren: () =>
      import("src/app/modules/admin/administration/roles/roles.module").then(
        (m) => m.RolesModule,
      ),
    canActivate: [PermissionGuard],
    data: { permissions: [PermissionsEnum.roles] },
  },
  {
    path: "api-keys",
    title: "API Key | Maxlan",
    loadChildren: () =>
      import(
        "src/app/modules/admin/administration/api-keys/api-keys.module"
      ).then((m) => m.ApiKeysModule),
    canActivate: [PermissionGuard],
    data: { permissions: [PermissionsEnum.apiKeys] },
  },
];

@NgModule({
  declarations: [],
  imports: [CommonModule, SharedModule, RouterModule.forChild(routes)],
})
export class AdministrationModule {}
